﻿namespace Sample
{
    using Infragistics.Win;
    using Infragistics.Win.UltraWinSchedule;
    using Infragistics.Win.UltraWinSchedule.DayView;
    using System;
    using System.Drawing;
    using System.Windows.Forms;

    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();           
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraDayView1.DrawFilter = new AppointmentDrawFilter();
            this.ultraCalendarInfo1.Owners.UnassignedOwner.Visible = false;
            this.ultraCalendarInfo1.Owners.Add("Welby", "Dr. Marcus Welby");
            this.ultraCalendarInfo1.Owners.Add("Kimble", "Dr. Richard Kimble");
            this.ultraCalendarInfo1.Owners.Add("Quincy", "Dr. Quincy");
            this.ultraCalendarInfo1.Owners.Add("Spencer", "Dr. Luke Spencer");
            this.ultraDayView1.GroupingStyle = DayViewGroupingStyle.OwnerWithinDate;
            this.ultraDayView1.TimeSlotInterval = TimeSlotInterval.ThirtyMinutes;

            var startDate1 = new DateTime(2017, 10, 24, 9, 0, 0);
            var endDate1 = new DateTime(2017, 10, 24, 10, 0, 0);
            var appointment1 = new Appointment(startDate1, endDate1);
            appointment1.Owner = this.ultraCalendarInfo1.Owners[1];
            appointment1.Subject = "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore";
            appointment1.Description = "Some test description 1";


            var startDate2 = new DateTime(2017, 10, 24, 11, 0, 0);
            var endDate2 = new DateTime(2017, 10, 24, 12, 0, 0);
            var appointment2 = new Appointment(startDate2, endDate2);
            appointment2.Owner = this.ultraCalendarInfo1.Owners[2];
            appointment2.Subject = "Meeting";
            appointment2.Description = "Some test description 2";

            this.ultraCalendarInfo1.Appointments.Add(appointment1);
            this.ultraCalendarInfo1.Appointments.Add(appointment2);
        }
    }


    public class AppointmentDrawFilter : IUIElementDrawFilter
    {
        #region DrawFilter
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            var textElement = drawParams.Element as EditorWithTextDisplayTextUIElement;
            if (textElement != null)
            {
                var appointmentElement = textElement.GetAncestor(typeof(AppointmentUIElement)) as AppointmentUIElement;
                if (appointmentElement != null)
                {
                    //Get the appointment subject and description
                    var appointment = appointmentElement.Appointment;
                    var appSubject = appointment.Subject;
                    var appDesc = appointment.Description;

                    //Get the size of the EditorWithTextDisplayTextUIElement
                    var textElementRect = drawParams.Element.Rect;
                    var textElementRectWidth = textElementRect.Width;
                    var textElementRectHeight = textElementRect.Height;
                    var textElementRectLeft = textElementRect.Left;
                    var textElementRectTop = textElementRect.Top;

                    //Create bold font
                    var boldFont = new Font(drawParams.Font, FontStyle.Bold);
                    //Draw the subject with the bold font
                    drawParams.Graphics.DrawString(appSubject, boldFont, Brushes.Black, textElementRect);

                    //Get the size of the subject text string
                    var appSubjectSize = drawParams.Graphics.MeasureString(appSubject, boldFont, textElementRectWidth);
                    var appSubjectWidth = (int)appSubjectSize.Width;
                    var appSubjectHeight = (int)appSubjectSize.Height;

                    //Create new Rectangle for the description
                    var appDescRectRight = textElementRectTop + appSubjectHeight;
                    var appDescRectHeight = textElementRectHeight - appSubjectHeight;
                    var appDescRect = new Rectangle(textElementRectLeft, appDescRectRight, textElementRectWidth, appDescRectHeight);
                    drawParams.Element.Rect.Offset(0, appSubjectHeight);

                    //Draw the appointment description
                    drawParams.Graphics.DrawString(appDesc, drawParams.Font, Brushes.Black, appDescRect);

                    boldFont.Dispose();
                    return true;
                }
            }

            return false;
        }
        #endregion DrawFilter

        #region GetPhasesToFilter
        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is EditorWithTextDisplayTextUIElement)
                return DrawPhase.BeforeDrawForeground;

            return DrawPhase.None;
        }
        #endregion //GetPhasesToFilter
    }
}
